RotatorFactory
==============

.. currentmodule:: xeofs

.. autoclass:: RotatorFactory
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RotatorFactory.__init__
      ~RotatorFactory.create_rotator
   
   

   
   
   